# pyramco
A complete wrapper class for the RAMCO API


version 0.9.6
2-23-2020


RAMCO API Documentation permalink:
<https://api.ramcoams.com/api/v2/ramco_api_v2_doc.pdf>


Requires the **requests** module:
<https://pypi.org/project/requests/>


your RAMCO API key should be set as an environment variable `RAMCO_API_KEY`



The contributors to Pyramco are not affiliated, associated, authorized, endorsed by, or in any way officially connected with RAMCO, The NATIONAL ASSOCIATION OF REALTORS®, or any of their subsidiaries or affiliates. The official RAMCO website can be found at https://ramcoams.com 

The name RAMCO, as well as related names, marks, emblems and images are registered trademarks of their respective owners.